@@ -35,14 +35,14 @@ _pkg_config = {
     'py_conf_inc_dir':    '/usr/include/python2.7',
     'py_inc_dir':         '/usr/include/python2.7',
     'py_lib_dir':         '/usr/lib/python2.7/config',
-    'py_version':         0x02070d,
+    'py_version':         0x02070e,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro',
+    'sip_config_args':    'CFLAGS=-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'sip_inc_dir':        '/usr/include/python2.7',
     'sip_mod_dir':        '/usr/lib/python2.7/site-packages',
-    'sip_version':        0x041303,
-    'sip_version_str':    '4.19.3',
+    'sip_version':        0x041306,
+    'sip_version_str':    '4.19.6',
     'universal':          ''
 }
 
@@ -50,7 +50,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
+    'CFLAGS':                   '-march=armv6 -mfloat-abi=hard -mfpu=vfp -O2 -pipe -fstack-protector-strong -fno-plt',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -99,7 +99,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro',
+    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
